# Models of Brittle-Matrix-Composite Beams

Deflection calculation of a composite beam to predict the ultimate and
serviceability limit states, considering the deflection limit.

Start beam as a notebook
[![Binder](https://mybinder.org/badge.svg)](https://mybinder.org/v2/gh/bmcs-group/bmcs_beam.git/master?filepath=webapps/bmcs_bending_app.ipynb)

Start beam in app mode
[![Binder](https://mybinder.org/badge.svg)](https://mybinder.org/v2/gh/bmcs-group/bmcs_beam/master?urlpath=apps%2Fwebapps/bmcs_bending_app.ipynb)

Start index in app mode
[![Binder](https://mybinder.org/badge.svg)](https://mybinder.org/v2/gh/bmcs-group/bmcs_beam/master?urlpath=apps%2Findex.ipynb)

